var plasma_entities = new Array(
    {
        id        : "plasma_frequency",
        name      : "Plasma frequency",
        dimension : "frequency",
        nspecies  : 1,
        section   : "waves",
        formula   : "%s1.getPlasmaFrequency()",
        wikiLink  : "Plasma_frequency"
    },
    {
        id        : "gyrofrequency",
        name      : "Gyrofrequency",
        dimension : "frequency",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getGyroFrequency(this.plasma.B)",
        wikiLink  : "Gyrofrequency"
    },

    {
        id        : "wigner_seitz_radius",
        name      : "Typical inter-particle distance",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getTypicalDistance()",
        wikiLink  : "Wigner-Seitz_radius"
    },
    {
        id        : "debye_length",
        name      : "Debye length",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getDebyeLength()",
        wikiLink  : "Debye_length"
    },
    {
        id        : "full_debye_length",
        name      : "Full Debye length",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "this.plasma.getFullDebyeLength(%s1)",
        wikiLink  : "Debye_length"
    },
    {
        id        : "gyroradius",
        name      : "Gyroradius",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getGyroRadius(this.plasma.B)",
        wikiLink  : "Gyroradius"
    },
    {
        id        : "distance_of_minimal_approach",
        name      : "Distance of minimal approach",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getMinApproachDistance()"
    },
    {
        id        : "inertial_length",
        name      : "Inertial length",
        dimension : "length",
        nspecies  : 1,
        section   : "waves",
        formula   : "%s1.getInertialLength()",
        wikiLink  : "Inertial_length"
    },
    {
        id        : "de_broglie_wavelength",
        name      : "De Broglie wavelength",
        dimension : "length",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getDeBroglieLength()",
        wikiLink  : "DeBroglie_wavelength"
    },

    {
        id        : "thermal_velocity",
        name      : "Thermal velocity",
        dimension : "velocity",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getThermalVelocity()",
        wikiLink  : "Thermal_velocity"
    },
    {
        id        : "alfven_velocity",
        name      : "Alfven velocity",
        dimension : "velocity",
        nspecies  : 0,
        section   : "waves",
        formula   : "this.plasma.getAlfvenVelocity(this.plasma.B)",
        wikiLink  : "Alfven_velocity"
    },

    {
        id        : "coupling_parameter",
        name      : "Coupling parameter",
        dimension : "none",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getCoupling()"
    },
    {
        id        : "typical_debye_screening",
        name      : "Typical Debye screening",
        dimension : "none",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "var r = %s1.getTypicalDistance()/%s1.getDebyeLength(); \
                     (1 + r)*Math.exp(-r)"
    },

    {
        id        : "transition_energy",
        name      : "Transition energy",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "this.plasma.getTransitionEnergy()"
    },
    {
        id        : "natural_linewidth",
        name      : "Natural linewidth",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "this.plasma.getNaturalWidth()"
    },
    {
        id        : "Fine_structure",
        name      : "Fine structure",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "this.plasma.getFineStructure()",
        wikiLink  : "Fine_structure"
    },
    {
        id        : "doppler_fwhm",
        name      : "Doppler FWHM",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "2*this.plasma.getDopplerHwhm()",
        wikiLink  : "Doppler_broadening"
    },
    {
        id        : "zeeman_splitting",
        name      : "Zeeman splitting",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "2*this.plasma.getZeemanSplitting()"
    },
    {
        id        : "total_stark_fwhm",
        name      : "Total Stark FWHM",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "2*this.plasma.getStarkHwhm()"
    },
    {
        id        : "stark_fwhm",
        name      : "Stark FWHM",
        dimension : "energy",
        nspecies  : 1,
        prepos    : "due to",
        section   : "spectroscopy",
        formula   : "2*this.plasma.getQsHwhm(%s1)*this.plasma.getStarkQuasistaticity(%s1)"
    },

    {
        id        : "qs_stark_fwhm",
        name      : "QS Stark FWHM",
        dimension : "energy",
        nspecies  : 1,
        prepos    : "due to",
        section   : "spectroscopy",
        formula   : "2*this.plasma.getQsHwhm(%s1)"
    },

    {
        id        : "dynamic_stark_range",
        name      : "Dynamic Stark range",
        dimension : "energy",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "this.plasma.getMicrofieldFrequency(%s1)"
    },

    {
        id        : "minimal_energy_distance",
        name      : "Minimal energy distance",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "this.plasma.getMinEnergyDistance()"
    },
    {
        id        : "plasmon_energy",
        name      : "Plasmon energy",
        dimension : "energy",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "this.plasma.e.getPlasmaFrequency()",
        wikiLink  : "Plasmon"
    },
    {
        id        : "fermi_energy",
        name      : "Fermi energy",
        dimension : "energy",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "this.plasma.getFermiEnergy()",
        wikiLink  : "Fermi_energy"
    },
    {
        id        : "chemical_potential",
        name      : "Chemical potential",
        dimension : "energy",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getChemicalPotential()",
        wikiLink  : "Chemical_potential"
    },

    {
        id        : "mass_density",
        name      : "Mass density",
        dimension : "mass_density",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getMassDensity()",
        wikiLink  : "Density"
    },
    {
        id        : "mass_density",
        name      : "Total mass density",
        dimension : "mass_density",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "this.plasma.getMassDensity()",
        wikiLink  : "Density"
    },

    {
        id        : "beta",
        name      : "Beta",
        dimension : "none",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "this.plasma.getBeta()",
        wikiLink  : "Beta_(plasma_physics)"
    },
    
    {
        id        : "stark_quasistaticity",
        name      : "Stark quasistaticity",
        dimension : "none",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "this.plasma.getStarkQuasistaticity(%s1)"
    },
    {
        id        : "static_to_dynamic_stark_ratio",
        name      : "Static/dynamic Stark ratio",
        dimension : "none",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "this.plasma.getStarkRatio(%s1)"
    },

    {
        id        : "transition_wavelength",
        name      : "Transition wavelength",
        dimension : "length",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "pf.base.Bohr.c/this.plasma.getTransitionEnergy()*(2*Math.PI)"
    },

    {
        id        : "transition_frequency",
        name      : "Transition frequency",
        dimension : "frequency",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "this.plasma.getTransitionEnergy()/(2*Math.PI)"
    },

    {
        id        : "holtsmark_field",
        name      : "Holtsmark field",
        dimension : "efield",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "%s1.getHoltsmarkField()"
    },

    {
        id        : "microfield_frequency",
        name      : "Microfield frequency",
        dimension : "frequency",
        nspecies  : 1,
        section   : "spectroscopy",
        formula   : "this.plasma.getMicrofieldFrequency(%s1)"
    },
    
    {
        id        : "cyclotron_losses",
        name      : "Cyclotron losses",
        dimension : "power_density",
        nspecies  : 1,
        section   : "radiation",
        formula   : "%s1.getCyclotronLosses(this.plasma.B)",
        wikiLink  : "Cyclotron_radiation"
    },
    
    {
        id        : "free-free_losses",
        name      : "Free-free losses",
        dimension : "power_density",
        nspecies  : 0,
        section   : "radiation",
        formula   : "this.plasma.getBremsstrahlungLosses()",
        wikiLink  : "Bremsstrahlung"
    },
    
    {
        id        : "dree-free_spectral_density",
        name      : "Free-free spectral density",
        dimension : "spectral_power_density",
        nspecies  : 0,
        section   : "radiation",
        formula   : "this.plasma.getBremsstrahlungSpectralDensity()",
        wikiLink  : "Bremsstrahlung"
    },
    
    {
        id        : "free-bound_losses",
        name      : "Free-bound losses",
        dimension : "power_density",
        nspecies  : 0,
        section   : "radiation",
        formula   : "this.plasma.getFreeBoundLosses()"
    },
    
    {
        id        : "free-bound_spectral_density",
        name      : "Free-bound spectral density",
        dimension : "spectral_power_density",
        nspecies  : 0,
        section   : "radiation",
        formula   : "this.plasma.getFreeBoundSpectralDensity()"
    },
    
    {
        id        : "bound-bound_losses",
        name      : "Bound-bound losses",
        dimension : "power_density",
        nspecies  : 0,
        section   : "radiation",
        formula   : "this.plasma.getBoundBoundLosses()"
    },
    
    {
        id        : "ideal_gas_pressure",
        name      : "Ideal gas pressure",
        dimension : "pressure",
        nspecies  : 1,
        section   : "fundamental",
        formula   : "%s1.getPressure()",
        wikiLink  : "Ideal_gas"
    },
    
    {
        id        : "total_pressure",
        name      : "Total pressure",
        dimension : "pressure",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "this.plasma.getPressure()"
    },
    
    {
        id        : "magnetic_field_pressure",
        name      : "Magnetic field pressure",
        dimension : "pressure",
        nspecies  : 0,
        section   : "fundamental",
        formula   : "this.plasma.getMagneticFieldPressure()",
        wikiLink  : "Magnetic_pressure"
    },
    
    {
        id        : "coulomb_logarithm",
        name      : "Coulomb logarithm",
        dimension : "none",
        nspecies  : 2,
        section   : "collisions",
        formula   : "this.plasma.getCoulombLog(%s1, %s2)",
        wikiLink  : "Coulomb_collision"
    },

    {
        id        : "relaxation_rate",
        name      : "Relaxation rate",
        dimension : "frequency",
        nspecies  : 2,
        section   : "collisions",
        formula   : "this.plasma.getRelaxationRate(%s1, %s2)"
    },

    {
        id        : "thomson_cross-section",
        name      : "Thomson cross-section",
        dimension : "area",
        nspecies  : 1,
        section   : "collisions",
        formula   : "%s1.getThomsonXsTotal()",
        wikiLink  : "Thomson_cross_section"
    },

    {
        id        : "classical_ionization_field",
        name      : "Classical ionization field",
        dimension : "efield",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "this.plasma.getClassicalIonizationField()"
    },
    {
        id        : "inglis_teller_field",
        name      : "Inglis-Teller field",
        dimension : "efield",
        nspecies  : 0,
        section   : "spectroscopy",
        formula   : "this.plasma.getInglisTellerField()",
        wikiLink  : "Inglis-Teller_equation"
    },
    {
        id        : "dreicer_field",
        name      : "Dreicer field",
        dimension : "efield",
        nspecies  : 0,
        section   : "collisions",
        formula   : "this.plasma.getDreicerField()"
    }
);
